@@ -454,7 +454,7 @@ class WordType(caching.base.CachingMixin,models.Model):
             base = WordToken.objects.all()
 
         Freq = float(base.filter(WordType=self).count())/float(base.filter(~Q(Category__CategoryType='Other'),~Q(Category__CategoryType='Pause'),~Q(Category__CategoryType='Disfluency')).count())
-        Freq = math.log(Freq * 1000000,10)
+        Freq = math.log((Freq * 1000000)+1,10)
         if subset=='all':
             self.Frequency = Freq
             self.save()
