@@ -224,7 +224,7 @@ def basic(request):
 
 @login_required
 def token_details(request,tokenNum):
-    token = WordToken.objects.get(pk=tokenNum)
+    token = WordToken.objects.select_related('Dialog','WordType','Dialog__Speaker').get(pk=tokenNum)
     if request.method == 'POST':
         form = RedoSpecGramForm(request.POST)
         if form.is_valid():
